@@ -14,11 +14,11 @@ strcmp <- function(s1, s2) {
     return(identical(s1, s2))
   } else if (length(s1) == 1 & length(s2) > 1) {
     # s1 is a scalar and s2 is a vector or a matrix
-    checks <- sapply(s2, function(s) s1 %in% s)
+    checks <- vapply(s2, function(s) s1 %in% s, vector("logical", 1))
     if (is(s2, "matrix")) checks <- matrix(checks, nrow(s2))
   } else if (length(s1) > 1 & length(s2) == 1) {
     # s1 is a vector/matrix, s2 is a scalar
-    checks <- sapply(s1, function(s) s2 %in% s)
+    checks <- vapply(s1, function(s) s2 %in% s, vector("logical"), 1)
     if (is(s1, "matrix")) checks <- matrix(checks, nrow(s1))
   } else {
     # s1 and s2 are vectors/matrices
